#! /bin/sh


makeAbsolute() {
    case $1 in
        /*)
            # already absolute, return it
            echo "$1"
            ;;
        *)
            # relative, prepend $2 made absolute
            echo `makeAbsolute "$2" "$PWD"`/"$1" | sed 's,/\.$,,'
            ;;
    esac
}

me=`which "$0"` # Search $PATH if necessary
if test -L "$me"; then
    # Try readlink(1)
    readlink=`type readlink 2>/dev/null` || readlink=
    if test -n "$readlink"; then
        # We have readlink(1), so we can use it. Assuming GNU readlink (for -f).
        me=`readlink -nf "$me"`
    else
        # No readlink(1), so let's try ls -l
        me=`ls -l "$me" | sed 's/^.*-> //'`
        base=`dirname "$me"`
        me=`makeAbsolute "$me" "$base"`
    fi
fi

bindir=`dirname "$me"`
libdir=`cd "$bindir/../lib" ; pwd`
LD_LIBRARY_PATH=$libdir:$libdir/qtcreator${LD_LIBRARY_PATH:+:$LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

export OE_QMAKE_AR="arm-poky-linux-gnueabi-ar"
export OE_QMAKE_CC="arm-poky-linux-gnueabi-gcc  -march=armv6 -mthumb-interwork -mfloat-abi=softfp  -mfpu=vfp --sysroot=/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi"
export OE_QMAKE_CFLAGS="-O2 -pipe -g -feliminate-unused-debug-types"
export OE_QMAKE_COMPILER="arm-poky-linux-gnueabi-gcc  -march=armv6 -mthumb-interwork -mfloat-abi=softfp  -mfpu=vfp --sysroot=/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi"
export OE_QMAKE_CXX="arm-poky-linux-gnueabi-g++  -march=armv6 -mthumb-interwork -mfloat-abi=softfp  -mfpu=vfp --sysroot=/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi"
export OE_QMAKE_CXXFLAGS="-O2 -pipe -g -feliminate-unused-debug-types -fvisibility-inlines-hidden"
export OE_QMAKE_LDFLAGS="-Wl,-O1 -Wl,--hash-style=gnu -Wl,--as-needed" 
export OE_QMAKE_LINK="arm-poky-linux-gnueabi-g++  -march=armv6 -mthumb-interwork -mfloat-abi=softfp  -mfpu=vfp --sysroot=/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi" 
export OE_QMAKE_STRIP="echo styles += mac fusion windows DEFINES += QT_NO_MTDEV" 
export QT_LIBS_DBUS="-ldbus-1"  
export QT_CFLAGS_DBUS="-I/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi/usr/include/dbus-1.0 -I/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi/usr/lib/dbus-1.0/include" 
export QT_HOST_CFLAGS_DBUS="-I/home/ix-tester/yoctoplace/poky/rpiHouse/tmp/sysroots/x86_64-linux/usr/include/dbus-1.0 -I/home/ix-tester/yoctoplace/poky/rpiHouse/tmp/sysroots/x86_64-linux/usr/lib/dbus-1.0/include" 
export QT_CFLAGS_PULSEAUDIO="-D_REENTRANT -I/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi/usr/include/glib-2.0 -I/opt/poky/1.6.2/sysroots/armv6-vfp-poky-linux-gnueabi/usr/lib/glib-2.0 include"  
export QT_LIBS_PULSEAUDIO="-lpulse-mainloop-glib -lpulse -lglib-2.0"
export QMAKE_INCDIR_LIBUDEV="QMAKE_LIBS_LIBUDEV = -ludev -lrt"
export QMAKE_X11_PREFIX="/usr" 
export QMAKE_XKB_CONFIG_ROOT="/usr/share/X11/xkb"
export QMAKE_CFLAGS_XCB=""
export QMAKE_LIBS_XCB="-lxcb-sync -lxcb-xfixes -lxcb-render -lxcb-randr -lxcb-image -lxcb-shm -lxcb-keysyms -lxcb-icccm -lxcb-shape -lxcb"  


exec "$bindir/qtcreator" ${1+"$@"}
